/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |        (DATASET 0002: NTIES TREATMENT EXPERIENCE QUESTIONNAIRE
 |                                (NTEQ))
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02884-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE t5ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) JAIL' 3='(3) PRISON' 4='(4) OTHER SITES' ;
  VALUE t6ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MALE' 2='(2) FEMALE' ;
  VALUE t8ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ENGLISH' 2='(2) SPANISH' 3='(3) OTHER' 4='(4) DEPENDS' ;
  VALUE t9ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t11fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t32fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) ENGLISH' 1='(1) SPANISH' ;
  VALUE t71fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) FIRST/LAST NAME MATCH INTAKE'
                  2='(2) FIRST/LAST NAME DO NOT MATCH INTAKE' ;
  VALUE t83fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) DOB MATCHES INTAKE' 2='(2) DOB DOES NOT MATCH INTAKE' ;
  VALUE t87fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) JAIL/DETENTION' 2='(2) OTHER' ;
  VALUE t89fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT INCARCERATED AT NRIQ BUT WAS AT NTEQ' ;
  VALUE t93fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) 2-6 DAYS' 3='(3) 1-3 WEEKS' 4='(4) 1-3 MONTHS' 5='(5) 4-12 MONTHS'
                  6='(6) MORE THAN 1 YEAR' ;
  VALUE t99m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t99m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE prgmtype  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CRITICAL POPULATIONS' 2='(2) CORRECTIONAL SETTINGS'
                  3='(3) NON-INCARCERATED OFFENDERS' 4='(4) TARGET CITIES'
                  5='(5) ADOLESCENT/JUVENILE JUSTICE' 6='(6) PUBLIC HOUSING' ;
  VALUE trt2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) IN-PATIENT' 2='(2) LONG-TERM RESIDENTIAL/IN-PATIENT'
                  3='(3) OUT-PATIENT METHADONE' 4='(4) AMBULATORY OUT-PATIENT' ;
  VALUE prg2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) AJJ/PH' 2='(2) CRIMINAL JUSTICE' 3='(3) TARGET CITIES' ;
  VALUE cell      -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CP/SR' 2='(2) CP/LR' 3='(3) CP/OP' 4='(4) TC/SR' 5='(5) TC/LR' 6='(6) TC/OP'
                  7='(7) CJ/SR' 8='(8) CJ/LR' 9='(9) CJ/OP' 10='(10) METHADONE' ;
  VALUE cell2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) METHADONE' 2='(2) NON-METHADONE OUT-PATIENT'
                  3='(3) SHORT-TERM RESIDENTIAL' 4='(4) LONG-TERM RESIDENTIAL'
                  5='(5) CORRECTIONAL SETTINGS' ;
  VALUE t115ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t117ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R STILL IN TREATMENT' ;
  VALUE t119ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT IN TREATMENT' ;
  VALUE t132ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) STILL IN TREATMENT' 2='(2) STOPPED TREATMENT' ;
  VALUE t141ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' ;
  VALUE t145ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 0='(0) 0'
                  1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6' 7='(7) 7' 8='(8) 8' 9='(9) 9'
                  10='(10) 10' 11='(11) 11' 12='(12) 12' 13='(13) 13' 14='(14) 14' 15='(15) 15' 16='(16) 16'
                  17='(17) 17' 18='(18) 18' 19='(19) 19' 20='(20) 20' 21='(21) 21' 22='(22) 22' 23='(23) 23'
                  24='(24) 24' 27='(27) 25-29' 32='(32) 30-34' 37='(37) 35-39' 42='(42) 40-44'
                  47='(47) 45-49' 50='(50) 50 OR MORE' ;
  VALUE t153ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t158ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) R HELPED DECIDE'
                  2='(2) SOMEONE AT PROGRAM DECIDED WITHOUT R' 3='(3) NO GOALS SET' ;
  VALUE t164m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t164m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO GOALS SET' ;
  VALUE t169ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' 4='(4) NO GOALS SET' ;
  VALUE t172ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY MUCH' 2='(2) SOMEWHAT' 3='(3) NOT AT ALL' 4='(4) NO GOALS SET' ;
  VALUE t176ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) PERSON EXISTS' 2='(2) NO SUCH PERSON' ;
  VALUE t183ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR MORE TIMES PER WEEK' 2='(2) 2-4 TIMES PER WEEK'
                  3='(3) 1 TIME PER WEEK' 4='(4) 2-4 TIMES PER MONTH'
                  5='(5) ONCE A MONTH OR LESS'
                  6='(6) TOTAL NUMBER OF SESSIONS (SPECIFY)' 7='(7) NO SUCH PERSON' ;
  VALUE t191ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 10 MINUTES' 2='(2) 10-29 MINUTES'
                  3='(3) 30-59 MINUTES' 4='(4) 1-2 HOURS' 5='(5) MORE THAN 2 HOURS'
                  6='(6) NO SUCH PERSON' ;
  VALUE t195ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY MUCH' 2='(2) SOMEWHAT' 3='(3) NOT AT ALL'
                  4='(4) NO SUCH PERSON' ;
  VALUE t198ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY MUCH' 2='(2) SOMEWHAT' 3='(3) NOT AT ALL'
                  4='(4) NO SUCH PERSON' ;
  VALUE t201ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO SUCH PERSON' ;
  VALUE t203ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t211ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t213ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t215ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t217ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t221ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t225ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t229ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-3' 4='(4) 4-10' 5='(5) 11 OR MORE' ;
  VALUE t233m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t233m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t241a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t241a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE t243ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR TWO DAYS' 3='(3) 3-5 DAYS' 4='(4) 6-7 DAYS'
                  5='(5) 3-10 DAYS' 6='(6) 11-20 DAYS' 7='(7) 21 DAYS OR MORE'
                  8='(8) TOTAL OVER TREATMENT PERIOD' ;
  VALUE t246m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t246m14f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t247ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t248ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR TWO DAYS' 3='(3) 3-5 DAYS' 4='(4) 6-7 DAYS'
                  5='(5) 3-10 DAYS' 6='(6) 11-20 DAYS' 7='(7) 21 DAYS OR MORE'
                  8='(8) TOTAL OVER TREATMENT PERIOD' ;
  VALUE t250ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE OF THE TIME' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' ;
  VALUE t251ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN HALF OF THE TIME'
                  2='(2) MORE THAN HALF OF THE TIME' ;
  VALUE t252ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t253ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR TWO DAYS' 3='(3) 3-5 DAYS' 4='(4) 6-7 DAYS'
                  5='(5) 3-10 DAYS' 6='(6) 11-20 DAYS' 7='(7) 21 DAYS OR MORE'
                  8='(8) TOTAL OVER TREATMENT PERIOD' ;
  VALUE t255ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR TWO DAYS' 3='(3) 3-5 DAYS' 4='(4) 6-7 DAYS'
                  5='(5) 3-10 DAYS' 6='(6) 11-20 DAYS' 7='(7) 21 DAYS OR MORE'
                  8='(8) TOTAL OVER TREATMENT PERIOD' ;
  VALUE t257ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t261ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) TOO HIGH' 2='(2) THE RIGHT AMOUNT' 3='(3) TOO LOW' ;
  VALUE t262m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t262m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t262m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t263ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t264m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t264m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t264m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t265ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t266m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t266m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t266m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t267ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t268ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE t269ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t270ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR TWO DAYS' 3='(3) 3-5 DAYS' 4='(4) 6-7 DAYS'
                  5='(5) 3-10 DAYS' 6='(6) 11-20 DAYS' 7='(7) 21 DAYS OR MORE'
                  8='(8) TOTAL OVER TREATMENT PERIOD' ;
  VALUE t272ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t273ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t274m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t274m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t274m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t277ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t278ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t279ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t280ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t281ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t282ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t284ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE t285m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m18f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE t285m19f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE t285m20f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m21f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t285m22f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t286ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) MORE THAN ONE TIME' ;
  VALUE t287ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) AGE 26 OR OLDER' ;
  VALUE t289ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t291ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t295ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR MORE TIMES PER WEEK' 2='(2) 2-4 TIMES PER WEEK'
                  3='(3) ONCE A WEEK' 4='(4) 2-3 TIMES A MONTH'
                  5='(5) ONCE A MONTH OR LESS' ;
  VALUE t297ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t298ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t299m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t299m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t299m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t300ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE t307ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) RS OWN APARTMENT/HOUSE'
                  2='(2) SOMEONE ELSES APARTMENT/HOUSE'
                  3='(3) HOTEL, MOTEL, ROOMING/BOARDING HOUSE/DOR'
                  4='(4) HOMELESS SHELTER/ON STREET' 5='(5) OTHER TYPE OF SHELTER'
                  6='(6) HOSPITAL' 7='(7) IN JAIL/PRISON/DETENTION/WORK RELEASE'
                  8='(8) GROUP HOME/TREATMENT CENTER' 9='(9) SOME OTHER PLACE' ;
  VALUE t309ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t310ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t312ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t313ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t315ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t316ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t321ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CHILDCARE NOT NECESSARY' ;
  VALUE t324m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t324m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t324m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t326ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CHILDCARE NOT NECESSARY' ;
  VALUE t331ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t333m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t333m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t333m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t334ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t335ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t336m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t336m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t336m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t338ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t339ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t340m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t340m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t340m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t341ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t342ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t343m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t343m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t343m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t344ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t346ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t347m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t347m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t347m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t348ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t349ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t350m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t350m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t350m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t357ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t358m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t362m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t362m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t362m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t364ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) RECEIVED DIPLOMA/GED PRIOR TO INTAKE' ;
  VALUE t365ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) HIGH SCHOOL DIPLOMA' 2='(2) GED CERTIFICATE'
                  3='(3) RECEIVED DIPLOMA/GED PRIOR TO INTAKE' ;
  VALUE t369ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VOCATIONAL/TRADE DIPLOMA' 2='(2) OTHER DIPLOMA'
                  3='(3) NO DIPLOMA' ;
  VALUE t374ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t376m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t381ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R HAS NEVER HAD A JOB' ;
  VALUE t383ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 WEEK' 2='(2) 2 WEEKS' 3='(3) 3 WEEKS' 4='(4) 4 WEEKS' 5='(5) 5 WEEKS'
                  6='(6) 6 WEEKS' 7='(7) 7 WEEKS' 8='(8) 8 OR MORE WEEKS' ;
  VALUE t384ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t385ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE t386ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1-20 HOURS' 2='(2) 21-35 HOURS' 3='(3) 36-45 HOURS'
                  4='(4) 46 HOURS OR MORE' ;
  VALUE t388ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t389m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t389m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t389m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t390ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t392ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t393m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t393m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t393m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t394ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE t398ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t401ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF INPATIENTS' ;
  VALUE t403ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t404m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t404m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t404m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t409ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE t410ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t417ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) S-S LESS THAN 2 WEEKS' ;
  VALUE t418ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) S-S LESS THAN 2 WEEKS'
                  4='(4) SKIPPED YES TO 417' ;
  VALUE t420ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t422ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t424ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t426m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t428m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t428m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t428m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t429ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t431ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t434m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t434m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t434m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t435ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t436ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t437m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t437m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t437m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) STILL IN TREATMENT' ;
  VALUE t438ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1-5 TIMES' 2='(2) 6-10 TIMES' 3='(3) 11-30 TIMES'
                  4='(4) 31 TIMES OR MORE' 5='(5) STILL IN TREATMENT' ;
  VALUE t446ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EXCELLENT' 2='(2) GOOD' 3='(3) FAIR' 4='(4) POOR' ;
  VALUE t448ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t452ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t454ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t455ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 NIGHT' 2='(2) 2 NIGHTS' 3='(3) 3 NIGHTS' 4='(4) 4 OR MORE NIGHTS' ;
  VALUE t457ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-3 DAYS' 4='(4) 4-10 DAYS'
                  5='(5) 11 OR MORE DAYS' ;
  VALUE t459m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t459m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t459m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t461ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t463m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t463m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t463m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t464ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t465m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t465m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t465m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t466ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME' 2='(2) 2 TIMES' 3='(3) 3 OR MORE TIMES'
                  4='(4) UNSPECIFIED (SEE NOTE 5)' ;
  VALUE t469ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t472ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t475m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t475m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t475m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t480ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10 OR MORE' ;
  VALUE t484ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE OF THE TIME' 2='(2) LESS THAN HALF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF THE TIME'
                  5='(5) EVERY TIME' ;
  VALUE t485ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t486m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t486m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t486m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t487ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t488ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t489m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t489m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t489m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t490ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE t491ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t492m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t492m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t492m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t500ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t509ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EDUCATION' 2='(2) FAMILY ISSUES' 3='(3) DRUG OR ALCOHOL USE'
                  4='(4) MENTAL HEALTH'
                  5='(5) MEDICAL EMOTIONS, NERVES OR AND HEALTH I'
                  6='(6) LEGAL PROBLEMS' 7='(7) JOB OR EMPLOYMENT PROBLEMS'
                  8='(8) INCOME OR FINANCIAL PROBLEMS' 9='(9) HOUSING ISSUES'
                  10='(10) OTHER' ;
  VALUE t513ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t516m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t518ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t519m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t519m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t519m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE t520ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE t523ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY MUCH' 2='(2) SOMEWHAT' 3='(3) NOT AT ALL' ;
  VALUE t547ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE t554ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE t128ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MONTHS' 2='(2) R < 48 HOURS DISCHARGE' 3='(3) STOPPED TREATMENT' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=672;
INPUT
        CASEID 1-7              T5 8-9                  T6 10-11
        T8 12-13                T9 14-15                T11 16-17
        T32 18-19               T71 20-21               T83 22-23
        T87 24-25               T89 26-27               T93 28-29
        T99M3 30-31             T99M4 32-33             PRGMTYPE 34-35
        TRT2 36-37              PRG2 38-39              CELL 40-41
        CELL2 42-43             T115 44-45              T117 46-47
        T119 48-49              T132 50-51              T141 52-53
        T145 54-55              T153 56-57              T158 58-59
        T164M1 60-61            T164M2 62-63            T164M3 64-65
        T164M4 66-67            T164M5 68-69            T164M6 70-71
        T164M7 72-73            T164M8 74-75            T164M9 76-77
        T164M10 78-79           T164M11 80-81           T164M12 82-83
        T164M13 84-85           T169 86-87              T172 88-89
        T176 90-91              T183 92-93              T191 94-95
        T195 96-97              T198 98-99              T201 100-101
        T203 102-103            T211 104-105            T213 106-107
        T215 108-109            T217 110-111            T221 112-113
        T225 114-115            T229 116-117            T233M1 118-119
        T233M2 120-121          T233M3 122-123          T233M4 124-125
        T233M5 126-127          T233M6 128-129          T233M7 130-131
        T233M8 132-133          T233M9 134-135          T233M10 136-137
        T233M11 138-139         T233M12 140-141         T233M13 142-143
        T241A1 144-145          T241A2 146-147          T241A3 148-149
        T241A4 150-151          T241A5 152-153          T241A6 154-155
        T241A7 156-157          T241A8 158-159          T241A9 160-161
        T241A10 162-163         T241A11 164-165         T241A12 166-167
        T243 168-169            T246M1 170-171          T246M2 172-173
        T246M3 174-175          T246M4 176-177          T246M5 178-179
        T246M6 180-181          T246M7 182-183          T246M8 184-185
        T246M9 186-187          T246M11 188-189         T246M12 190-191
        T246M13 192-193         T246M14 194-195         T247 196-197
        T248 198-199            T250 200-201            T251 202-203
        T252 204-205            T253 206-207            T255 208-209
        T257 210-211            T261 212-213            T262M1 214-215
        T262M2 216-217          T262M3 218-219          T263 220-221
        T264M1 222-223          T264M2 224-225          T264M3 226-227
        T265 228-229            T266M1 230-231          T266M2 232-233
        T266M3 234-235          T267 236-237            T268 238-239
        T269 240-241            T270 242-243            T272 244-245
        T273 246-247            T274M1 248-249          T274M2 250-251
        T274M3 252-253          T277 254-255            T278 256-257
        T279 258-259            T280 260-261            T281 262-263
        T282 264-265            T284 266-267            T285M7 268-269
        T285M9 270-271          T285M10 272-273         T285M12 274-275
        T285M13 276-277         T285M16 278-279         T285M17 280-281
        T285M18 282-283         T285M19 284-285         T285M20 286-287
        T285M21 288-289         T285M22 290-291         T286 292-293
        T287 294-295            T289 296-297            T291 298-299
        T295 300-301            T297 302-303            T298 304-305
        T299M1 306-307          T299M2 308-309          T299M3 310-311
        T300 312-313            T307 314-315            T309 316-317
        T310 318-319            T312 320-321            T313 322-323
        T315 324-325            T316 326-327            T321 328-329
        T324M1 330-331          T324M2 332-333          T324M3 334-335
        T326 336-337            T331 338-339            T333M1 340-341
        T333M2 342-343          T333M3 344-345          T334 346-347
        T335 348-349            T336M1 350-351          T336M2 352-353
        T336M3 354-355          T338 356-357            T339 358-359
        T340M1 360-361          T340M2 362-363          T340M3 364-365
        T341 366-367            T342 368-369            T343M1 370-371
        T343M2 372-373          T343M3 374-375          T344 376-377
        T346 378-379            T347M1 380-381          T347M2 382-383
        T347M3 384-385          T348 386-387            T349 388-389
        T350M1 390-391          T350M2 392-393          T350M3 394-395
        T357 396-397            T358M1 398-399          T358M2 400-401
        T358M3 402-403          T358M4 404-405          T358M5 406-407
        T358M6 408-409          T358M7 410-411          T362M1 412-413
        T362M2 414-415          T362M3 416-417          T364 418-419
        T365 420-421            T369 422-423            T374 424-425
        T376M1 426-427          T381 428-429            T383 430-431
        T384 432-433            T385 434-435            T386 436-437
        T388 438-439            T389M1 440-441          T389M2 442-443
        T389M3 444-445          T390 446-447            T392 448-449
        T393M1 450-451          T393M2 452-453          T393M3 454-455
        T394 456-457            T398 458-459            T401 460-461
        T403 462-463            T404M1 464-465          T404M2 466-467
        T404M3 468-469          T409 470-471            T410 472-473
        T417 474-475            T418 476-477            T420 478-479
        T422 480-481            T424 482-483            T426M1 484-485
        T426M2 486-487          T426M3 488-489          T426M4 490-491
        T426M5 492-493          T426M6 494-495          T426M7 496-497
        T426M8 498-499          T426M9 500-501          T426M10 502-503
        T428M1 504-505          T428M2 506-507          T428M3 508-509
        T429 510-511            T431 512-513            T434M1 514-515
        T434M2 516-517          T434M3 518-519          T435 520-521
        T436 522-523            T437M1 524-525          T437M2 526-527
        T437M3 528-529          T438 530-531            T446 532-533
        T448 534-535            T452 536-537            T454 538-539
        T455 540-541            T457 542-543            T459M1 544-545
        T459M2 546-547          T459M3 548-549          T461 550-551
        T463M1 552-553          T463M2 554-555          T463M3 556-557
        T464 558-559            T465M1 560-561          T465M2 562-563
        T465M3 564-565          T466 566-567            T469 568-569
        T472 570-571            T475M1 572-573          T475M2 574-575
        T475M3 576-577          T480 578-579            T484 580-581
        T485 582-583            T486M1 584-585          T486M2 586-587
        T486M3 588-589          T487 590-591            T488 592-593
        T489M1 594-595          T489M2 596-597          T489M3 598-599
        T490 600-601            T491 602-603            T492M1 604-605
        T492M2 606-607          T492M3 608-609          T500 610-611
        T509 612-613            T513 614-615            T516M1 616-617
        T516M2 618-619          T516M3 620-621          T516M4 622-623
        T516M5 624-625          T516M6 626-627          T516M7 628-629
        T516M8 630-631          T516M9 632-633          T516M10 634-635
        T518 636-637            T519M1 638-639          T519M2 640-641
        T519M3 642-643          T520 644-645            T523 646-647
        T547 648-649            T548 650-652            T549 653-654
        T550 655-656            T551 657-659            T552 660-661
        T553 662-663            T554 664-665            T555 666-667
        T556 668-670            T128 671-672            ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASEID'
   T5      = 'NRIQ SETTING'
   T6      = 'GENDER'
   T8      = 'NRIQ: LANGUAGE PREFERENCE'
   T9      = 'NRIQ: HS DIPLOMA/GED'
   T11     = 'OTHER CHILDREN RAISED'
   T32     = 'NTEQ: LANGUAGE FLAG'
   T71     = 'NRIQ & NTEQ NAMES MATCH'
   T83     = 'NRIQ & NTEQ DOB MATCH'
   T87     = 'SCRN CHECK V: NTEQ SETTING'
   T89     = 'OUT OF CUSTODY SINCE NRIQ?'
   T93     = 'LENGTH OF CURRENT INCARCERATION'
   T99M3   = 'SERVING A SENTENCE?'
   T99M4   = 'SOMETHING ELSE?'
   PRGMTYPE= 'PROGRAM TYPE'
   TRT2    = 'REVISED TREATMENT MODALITY'
   PRG2    = 'REVISED PROGRAM TYPE'
   CELL    = 'ANALYSIS VARIABLE'
   CELL2   = 'ANALYSIS VARIABLE V.2'
   T115    = 'INTV CHECK I: SDU RECS SHOW DISCHARGE?'
   T117    = 'SDU SHOWS: R STOPPED TREATMENT'
   T119    = 'SDU SHOWS: R STILL IN TREATMENT?'
   T132    = 'FINAL STATUS: IN OR OUT OF TREATMENT?'
   T141    = 'CONFIRM DATES?'
   T145    = 'LENGTH IN WKS OF NTEQ REF PERIOD'
   T153    = 'R SAW TREATMENT PLAN?'
   T158    = 'R HELPED DEVELOP TX PLAN?'
   T164M1  = 'GET OFF ILLEGAL DRUGS'
   T164M2  = 'GET OFF METHADONE/ANTABUSE/TREATMNT DRUG'
   T164M3  = 'QUIT DRINKING'
   T164M4  = 'IMPROVE PHYSICAL HEALTH'
   T164M5  = 'IMPROVE MENTAL HEALTH/EMOTIONAL PROBLEMS'
   T164M6  = 'JOB-RELATED'
   T164M7  = 'REDUCE FINANCIAL PROBLEMS'
   T164M8  = 'GET HOUSING'
   T164M9  = 'SCHOOL-RELATED'
   T164M10 = 'STOP COMMITTING CRIMES'
   T164M11 = 'REDUCE LEGAL PROBLEMS'
   T164M12 = 'IMPROVE FAMILY RELATIONS'
   T164M13 = 'OTHER'
   T169    = 'S-S AGREEMENT WITH TX GOALS'
   T172    = 'S-S ADHERENCE TO TX GOALS'
   T176    = 'S-S PRIMARY PROVIDER'
   T183    = 'S-S TIME/WK WITH 1-ARY PROVIDER'
   T191    = 'LENGTH OF SESSIONS WITH 1-ARY PROVIDER'
   T195    = 'AGREEMENT WITH 1-ARY PROVIDER'
   T198    = 'UNDERSTANDING BY 1-ARY PROVIDER'
   T201    = '1-ARY PROV SPEAKS PREFERRD LANGUAGE?'
   T203    = 'S-S RECVD SERVS FOR SPANISH-SPEAKERS'
   T211    = 'S-S # APPTS MISSD FOR INCARCERATION'
   T213    = 'S-S # APPTS MISSED FOR ILLNESS'
   T215    = 'S-S # APPTS MISSED FOR ILL RELATIVE'
   T217    = 'S-S # APPTS MISSED FOR OTHER REASON'
   T221    = 'S-S TX MISSED 1 WK OR MORE?'
   T225    = 'S-S TOTAL # DAYS SERV REC''D FROM PROGM'
   T229    = 'S-S TOTAL # DAYS REC''D SERV NOT FROM PR'
   T233M1  = 'REASON STOPPED TX/COMPLETED TX PLAN/GRAD'
   T233M2  = 'REASON STOPPED TX/KICKED OUT OF PROG BY'
   T233M3  = 'REASON STOPPED TX/DID NOT WANT TO BE THE'
   T233M4  = 'REASON STOPPED TX/TX NOT SUCCESSFUL/KEEP'
   T233M5  = 'REASON STOPPED TX/TRANSFERRED TO ANOTHER'
   T233M6  = 'REASON STOPPED TX/CHANGES IN ELIGIBILITY'
   T233M7  = 'REASON STOPPED TX/BECAME INCARCERATED'
   T233M8  = 'REASON STOPPED TX/LOGIST.PROB/TOO DIFFIC'
   T233M9  = 'REASON STOPPED TX/COULDN''T AFFORD IT'
   T233M10 = 'REASON STOPPED TX/PRESSURE FROM FAMILY &'
   T233M11 = 'REASON STOPPED TX/LEFT AREA'
   T233M12 = 'REASON STOPPED TX/OTHER'
   T233M13 = 'REASON STOPPED TX/NONE GIVEN'
   T241A1  = 'INHALANTS,GLUE,WHITE OUT,POPPERS'
   T241A2  = 'MARIJUANA OR HASHISH?'
   T241A3  = 'CRACK,NOT COCAINE POWDER?'
   T241A4  = 'COCAINE POWDER?'
   T241A5  = 'PCP OR ANGEL DUST?'
   T241A6  = 'PSYCHEDELICS SUCH AS ACID/MESCALINE?'
   T241A7  = 'HEROIN?'
   T241A8  = 'ILLEGAL METHADONE?'
   T241A9  = 'OTHER NARCOTICS (MORPHINE/OPIUM/ETC)'
   T241A10 = 'UPPERS (SPEED,CRANK,AMPHETAMNES/ETC)'
   T241A11 = 'DOWNERS (BARBITURATES/SECONAL/ETC)'
   T241A12 = 'OTHER DRUGS (NOT ALCOHOL)TO GET HIGH'
   T243    = 'S-S AVG # DAYS PER WK/MO DRUGS USED'
   T246M1  = 'R USED: INHALANTS?'
   T246M2  = 'R USED: MARIJUANA/HASHISH?'
   T246M3  = 'R USED: CRACK?'
   T246M4  = 'R USED: COCAINE POWDER?'
   T246M5  = 'R USED: PCP?'
   T246M6  = 'R USED: HALLUCINOGENS OR PSYCHEDELICS?'
   T246M7  = 'R USED: UPPERS?'
   T246M8  = 'R USED: DOWNERS?'
   T246M9  = 'R USED: HEROIN?'
   T246M11 = 'R USED: OTHER NARCOTICS?'
   T246M12 = 'R USED: ALCOHOL?'
   T246M13 = 'R USED: OTHER DRUG'
   T246M14 = 'R USED: NONE'
   T247    = 'S-S INJECTED DRUGS?'
   T248    = 'S-S AVG # DAYS PER WK/MO INJECTED DRUGS'
   T250    = 'S-S HOW OFTN SHARED STRANGER''S NDLE'
   T251    = 'S-S HOW OFTEN CLEANED NEEDLE'
   T252    = 'S-S DRANK ALCOHOL?'
   T253    = 'S-S AVG # DAYS IN WK/MO DRANK ALCOHL'
   T255    = 'S-S AVG # DAYS PER WK/MO GOT DRUNK'
   T257    = 'S-S MEDICINES FOR DRUG/ALC PROBS?'
   T261    = 'APPROPRIATE DOSES OF METHADONE'
   T262M1  = 'DOCTOR PRESCRIBED MEDCIN WORKED AT PGM'
   T262M2  = 'DOCTOR WORKED AT SOME PLACE PGM SENT R'
   T262M3  = 'DOCTOR WORKED SOMEWHERE ELSE'
   T263    = 'S-S, ATTENDED 12-STEP?'
   T264M1  = 'R ATT''D CA/NA/AA MEETINGS AT PGM?'
   T264M2  = 'CA/NA/AA MEETINGS AT PLACE PGM SENT R?'
   T264M3  = 'ATT''D CA/NA/AA MEETINGS SOMEWHERE ELSE'
   T265    = 'S-S OTHER DRUG/ALCOHOL COUNSELING'
   T266M1  = 'DRUG/ALCOHOL COUNSELING AT PGM?'
   T266M2  = 'DRUG/ALCOHOL COUNSELING PLACE PGM SENT R'
   T266M3  = 'DRUG/ALCOHOL COUNSELING SOMEWHERE ELSE?'
   T267    = '# SESSIONS OF COUNSELING ATTENDED'
   T268    = 'HELPFULNESS OF COUNSELING REC''D'
   T269    = 'S-S URINE TESTED?'
   T270    = 'AVG # DAYS IN WK/MO TESTD FOR DRUG'
   T272    = 'ATTENDED 12-STEP SINCE PROGM?'
   T273    = 'REC''D DRUG/ALCOHOL TX SINCE PROGM?'
   T274M1  = 'DRUG/ALCOHOL TREATMENT AT PGM?'
   T274M2  = 'DRUG/ALCOHOL TREATMENT PLACE PGM SENT R?'
   T274M3  = 'DRUG/ALCOHOL TREATMENT SOMEWHERE ELSE?'
   T277    = 'S-S DWI/DUI?'
   T278    = 'S-S SOLD DRUGS?'
   T279    = 'S-S PROSTITUTED?'
   T280    = 'S-S OTHER ACQUISITIVE CRIMES?'
   T281    = 'S-S BEAT SOMEONE UP?'
   T282    = 'S-S OTHER ILLEGAL ACTIVITIES?'
   T284    = 'S-S ARRESTED/BOOKED OR IN CUSTODY?'
   T285M7  = 'CHARGES: BOOKMAKING/NUMBERS/GAMBLING?'
   T285M9  = 'CHARGES: MOTOR VEHICLE THEFT?'
   T285M10 = 'CHARGES: SHOPLIFTING?'
   T285M12 = 'CHARGES: ARMED ROBBERY/ROBBERY BY FORCE?'
   T285M13 = 'CHARGES: OTHER THEFT (LARCENCY/MUGGING?)'
   T285M16 = 'CHARGES: AGGRAVTD ASSAULT/INTENT KILL?'
   T285M17 = 'CHARGES: SIMPLE ASSAULT/FIGHTING?'
   T285M18 = 'CHARGES: FORCIBLE/STATUTORY RAPE?'
   T285M19 = 'CHARGES: MURDER/MANSLAUGHTER?'
   T285M20 = 'CHARGES: CURFEW VIOLATION/TRUANCY/RUNAW?'
   T285M21 = 'CHARGES: OTHER?'
   T285M22 = 'CHARGES: CANNOT CODE?'
   T286    = 'S-S # TIMES ARRESTED/BKED/IN CUSTODY'
   T287    = 'ON JUVENILE PROBATION/PAROLE/COND RELEAS'
   T289    = 'ON ADULT PROBATION/PAROLE/COND RELEASE?'
   T291    = 'ON WORK RELEASE?/ELEC MONITOR/OTHER SUPE'
   T295    = 'HOW OFTEN TALK TO OFFICER'
   T297    = 'CHARGES PENDING?'
   T298    = 'S-S REC''D LEGAL SERVICES?'
   T299M1  = 'RECVD LEGAL SERVICES AT PGM?'
   T299M2  = 'LEGAL SERVICES AT PLACE PGM SENT R?'
   T299M3  = 'LEGAL SERVICES SOMEWHERE ELSE?'
   T300    = 'HELPFULNESS OF LEGAL SERVICES REC''D'
   T307    = 'PLACE R STAYED LAST NIGHT-C'
   T309    = 'PUBLIC HOUSING?'
   T310    = 'SHOOTNG KNIFNG NEAR HOME LAST 7 DAYS'
   T312    = 'LIVING WITH SPOUSE/PARTNER?'
   T313    = 'LIVING WITH CHILDREN(UNDER 18)'
   T315    = 'S-S STAYED IN HOMELESS SHELTER?'
   T316    = 'S-S STAYED IN OTHER SHELTER?'
   T321    = 'S-S REC''D CHILD CARE HELP?'
   T324M1  = 'RECVD CHILD CARE HELP AT PGM?'
   T324M2  = 'CHILD CARE HELP AT PLACE PGM SENT R?'
   T324M3  = 'CHILD CARE HELP SOMEWHERE ELSE?'
   T326    = 'MISSED TX FOR LACK OF CHILDCARE?'
   T331    = 'S-S REC''D PARENTING TRAINING'
   T333M1  = 'RECVD PARENTING TRAINING AT PGM?'
   T333M2  = 'PARENTING TRAINING AT PLACE PGM SENT R?'
   T333M3  = 'PARENTING TRAINING SOMEWHERE ELSE?'
   T334    = '# TIMES RECEIVED PARENTING TRAINING'
   T335    = 'S-S REC''D SERVICES FOR ABUSED?'
   T336M1  = 'RECVD SERVICES FOR ABUSED AT PGM?'
   T336M2  = 'SERVICES FOR ABUSED AT PLACE PGM SENT R?'
   T336M3  = 'SERVICES FOR ABUSED SOMEWHERE ELSE?'
   T338    = '# OF SESSIONS FOR ABUSED ATTENDED?'
   T339    = 'S-S SERVS FOR OTHER FAMILY PROBS?'
   T340M1  = 'RECVD SERVS FOR OTH FAMILY PROBS AT PGM?'
   T340M2  = 'SERVS FOR FAMLY PROBS PLACE PGM SENT R'
   T340M3  = 'SERVS FOR FAMLY PROBS SOMEWHERE ELSE?'
   T341    = '# TIMES OTHER FAMILY PROBS SERVS'
   T342    = 'S-S REC''D ASSERTIVENESS TRAINING?'
   T343M1  = 'RECVD ASSERTIVENESS TRAINING AT PGM?'
   T343M2  = 'ASSERTIVENESS TRAINING PLACE PGM SENT R?'
   T343M3  = 'ASSERTIVENESS TRAINING SOMEWHERE ELSE?'
   T344    = '# TIMES ATTENDED ASSERT TRNG'
   T346    = 'S-S REC''D LIFE SKILLS TRNG?'
   T347M1  = 'RECVD LIFE SKILLS TRNG AT PGM?'
   T347M2  = 'LIFE SKILLS TRNG AT PLACE PGM SENT R?'
   T347M3  = 'LIFE SKILLS TRNG SOMEWHERE ELSE?'
   T348    = '# LIFE SKILLS TRNG SESSIONS ATTND?'
   T349    = 'S-S REC''D SERVICES FOR TEENS?'
   T350M1  = 'RECVD SERVICES FOR TEENS AT PGM?'
   T350M2  = 'SERVICES FOR TEENS AT PLACE PGM SENT R?'
   T350M3  = 'SERVICES FOR TEENS SOMEWHERE ELSE?'
   T357    = 'S-S ATTENDED SCHOOL?'
   T358M1  = 'R ATT''D ELEMENTARY/MIDDLE/JUN HIGH'
   T358M2  = 'R ATT''D HIGH SCHL/HIGH SCHL PGM?'
   T358M3  = 'R ATT''D GED PROGRAM?'
   T358M4  = 'R ATT''D JUNIOR (2-YR) COLLEGE?'
   T358M5  = 'R ATT''D 4-YR COLLEGE/UNIVERSITY?'
   T358M6  = 'R ATT''D TECHNICAL/TRADE/VOCATIONAL SCHL'
   T358M7  = 'R ATT''D OTHER'
   T362M1  = 'R RECVD SCHOOLING AT PGM?'
   T362M2  = 'R RECVD SCHOOLING AT PLACE PGM SENT R?'
   T362M3  = 'R RECVD SCHOOLING SOMEWHERE ELSE?'
   T364    = 'S-S REC''D HS DIPLOMA/GED?'
   T365    = 'REC''D HS DIPLOMA OR GED'
   T369    = 'DIPLOMA RECEIVED'
   T374    = 'S-S REC''D ENGLISH LANGUAGE CLASSES?'
   T376M1  = 'ENGLISH CLASSES AT PGM?'
   T381    = 'S-S R EMPLOYED?'
   T383    = 'S-S # WEEKS EMPLOYED-SP'
   T384    = 'CURRENTLY EMPLOYED?'
   T385    = 'HOW LONG AT CURRENT JOB?'
   T386    = 'AVERAGE # HOURS WORKED/WEEK-SP'
   T388    = 'S-S REC''D JOB SKILLS SERVICES?'
   T389M1  = 'RECVD JOB SKILLS SERVCS AT PGM?'
   T389M2  = 'RECVD JOB SKILLS SERVCS PLACE PGM SENT R'
   T389M3  = 'RECVD JOB SKILLS SERVCS SOMEWHERE ELSE?'
   T390    = '# SESSIONS ATTENDED FOR JOB SKILLS'
   T392    = 'S-S REC''D HELP WITH HOUSING PROBS?'
   T393M1  = 'RECVD HOUSING HELP AT PGM?'
   T393M2  = 'RECVD HOUSING HELP AT PLACE PGM SENT R?'
   T393M3  = 'RECVD HOUSING HELP SOMEWHERE ELSE?'
   T394    = 'HELPFULNESS OF HOUSING HELPERS'
   T398    = 'S-S PROGRAM PROVIDED TRANSPORTATION?'
   T401    = 'R ABLE TO GET TO TX WITH TRANS HELP'
   T403    = 'S-S HELP COLLECTING GOV''T PAYMTS'
   T404M1  = 'HELP COLLECT GOV''T PAYMTS AT PGM?'
   T404M2  = 'HELP COLLECT GOV PAYS PLACE PGM SENT R?'
   T404M3  = 'HELP COLLECT GOV''T PAYS SOMEWHERE ELSE?'
   T409    = 'HELPFULNESS PAYMT COLLECTION AIDES'
   T410    = 'S-S PGM HELPED ALIMONY/CHILD SUPPT'
   T417    = 'S-S SEVERELY DEPRESSED FOR 2 WEEKS?'
   T418    = 'S-S LOST INTEREST IN LIFE 2 WEEKS?'
   T420    = 'S-S ATTEMPTED SUICIDE?'
   T422    = 'S-S SUICIDAL THOUGHTS?'
   T424    = 'S-S REC''D MENTAL HEALTH TX?'
   T426M1  = 'DEPRESSION,MANIC DEPRESSION,SAD,BLUE,LOW'
   T426M2  = 'FEAR,ANXIETY,FEARFUL,PHOBIA,STRESS DISOR'
   T426M3  = 'SCHIZOPHRENIA'
   T426M4  = 'PARANOIA,PSYCHOSIS'
   T426M5  = 'THOUGHTS OF SUICIDE,ATTEMPTED SUICIDE'
   T426M6  = 'ANY UPSETTING EXPERIENCE,LOST JOB,RAPE'
   T426M7  = 'OTHER SPECIFIC TYPES OF MENTAL DISORDERS'
   T426M8  = 'PERSONALITY DISORDER/PROBLEMS'
   T426M9  = 'OTHER GENRL EXPLANATION,TENSION,STRESS'
   T426M10 = 'OTHER'
   T428M1  = 'RECVD MENTAL HEALTH COUNSLNG AT PGM?'
   T428M2  = 'MENTAL HEALTH COUNSLNG PLACE PGM SENT R?'
   T428M3  = 'MENTAL HEALTH COUNSLNG SOMEWHERE ELSE?'
   T429    = '# TIMES MENTAL HEALTH TX REC''D'
   T431    = 'S-S PSYCHOTROPIC DRUGS TAKEN?'
   T434M1  = 'DOCTOR PRESCRIBD MED WORKED AT PGM'
   T434M2  = 'DOCTOR WORKED AT SOME PLACE PGM SENT R'
   T434M3  = 'DOCTOR WORKED SOMEWHERE ELSE'
   T435    = '24 HR MENTAL HEALTH VISIT SINCE PGM?'
   T436    = 'OTHER MENTAL HEALTH TX SINCE PROGM?'
   T437M1  = 'RECVD MENTAL HEALTH TX AT PGM?'
   T437M2  = 'MENTAL HEALTH TX AT PLACE PGM SENT R?'
   T437M3  = 'MENTAL HEALTH TX SOMEWHERE ELSE?'
   T438    = '# MENTAL HEALTH VISITS SINCE PROGM?'
   T446    = 'S-S GENERAL HEALTH'
   T448    = 'S-S HEALTH PROBLEMS?'
   T452    = 'HEALTH PROBLEM FOR > 1WEEK?'
   T454    = 'S-S SPENT NIGHT IN HOSPITAL?'
   T455    = 'S-S # NIGHTS SPENT IN HOSPITAL-SP'
   T457    = 'S-S # DAYS REC''D MEDICAL SERVICES'
   T459M1  = 'RECVD ANY MEDICAL SERVCS AT PGM?'
   T459M2  = 'ANY MEDICAL SERVCS AT PLACE PGM SENT R?'
   T459M3  = 'ANY MEDICAL SERVCS SOMEWHERE ELSE?'
   T461    = 'S-S TESTED FOR TB?'
   T463M1  = 'R RECVD TB TEST AT PGM?'
   T463M2  = 'R RECVD TB TEST AT PLACE PGM SENT R?'
   T463M3  = 'R RECVD TB TEST SOMEWHERE ELSE?'
   T464    = 'S-S TESTED AIDS'
   T465M1  = 'R RECVD AIDS TEST AT PGM?'
   T465M2  = 'R RECVD AIDS TEST AT PLACE PGM SENT R?'
   T465M3  = 'R RECVD AIDS TEST SOMEWHERE ELSE?'
   T466    = 'S-S # AIDS TEST TAKEN-SP'
   T469    = 'R KNOWS AIDS TEST RESULTS?'
   T472    = 'S-S REC''D AIDS PREVENTION SERVICES?'
   T475M1  = 'R RECVD AIDS PREVENTION SERVCS AT PGM?'
   T475M2  = 'AIDS PREVENTION SERVCS PLACE PGM SENT R?'
   T475M3  = 'AIDS PREVENTION SERVCS SOMEWHERE ELSE?'
   T480    = 'S-S # OF SEX PARTNERS'
   T484    = 'QTG8A S-S CONDOM USE DURING SEX'
   T485    = 'S-S REC''D FAMILY PLANNING SERVICES'
   T486M1  = 'RECVD FAMILY PLANNING SERVCS AT PGM?'
   T486M2  = 'FAMILY PLANNING SERVCS PLACE PGM SENT R?'
   T486M3  = 'FAMILY PLANNING SERVCS SOMEWHERE ELSE?'
   T487    = 'S-S PREGNANT?'
   T488    = 'S-S REC''D MEDICAL PREGCY CARE?'
   T489M1  = 'R RECVD MED CARE FOR PREGCY AT PGM?'
   T489M2  = 'MED CARE FOR PREGCY AT PLACE PGM SENT R?'
   T489M3  = 'MED CARE FOR PREGCY SOMEWHERE ELSE?'
   T490    = 'S-S # TIMES MED CARE FOR PREGCY'
   T491    = 'S-S REC''D NON-MED SERVS FOR PREGCY'
   T492M1  = 'R RECVD NON-MED PREGCY CARE AT PGM?'
   T492M2  = 'NON-MED PREGCY CARE AT PLACE PGM SENT R?'
   T492M3  = 'NON-MED PREGCY CARE SOMEWHERE ELSE?'
   T500    = 'S-S REC''D OTHER SERVICES?'
   T509    = 'S-S MOST USEFUL SERVICE REC''D-C'
   T513    = 'S-S SERVICE NEEDED, NOT REC''D?'
   T516M1  = 'HELP NOT RECVD: EDUCATION'
   T516M2  = 'HELP NOT RECVD: FAMILY ISSUES'
   T516M3  = 'HELP NOT RECVD: DRUG OR ALCOHOL USE'
   T516M4  = 'HELP NOT RECVD: EMOTIONS,NERVES,MENTAL H'
   T516M5  = 'HELP NOT RECVD: MEDICAL/HEALTH ISSUES'
   T516M6  = 'HELP NOT RECVD: LEGAL PROBLEMS'
   T516M7  = 'HELP NOT RECVD: JOB/EMPLOYMENT PROBLEMS'
   T516M8  = 'HELP NOT RECVD: INCOME/FINANCIAL PROBLMS'
   T516M9  = 'HELP NOT RECVD: HOUSING ISSUES'
   T516M10 = 'HELP NOT RECVD: OTHER'
   T518    = 'S-S REC''D SERVICES FOR LIFE AFTER'
   T519M1  = 'SERVICES RECVD AFTER TX AT PGM?'
   T519M2  = 'SERVICES AFTER TX AT PLACE PGM SENT R?'
   T519M3  = 'SERVICES RECVD AFTER TX SOMEWHERE ELSE?'
   T520    = 'HELPFULNESS OF LIFE AFTER TX SERVS'
   T523    = 'OVERALL HELPFULNESS OF PROGRAM'
   T547    = 'ELAPSED MINUTES FOR SCR'
   T548    = 'ELAPSED MINUTES FOR A'
   T549    = 'ELAPSED MINUTES FOR B'
   T550    = 'ELAPSED MINUTES FOR C'
   T551    = 'ELAPSED MINUTES FOR D'
   T552    = 'ELAPSED MINUTES FOR E'
   T553    = 'ELAPSED MINUTES FOR F'
   T554    = 'ELAPSED MINUTES FOR G'
   T555    = 'ELAPSED MINUTES FOR H'
   T556    = 'ELAPSED MINUTES FOR K'
   T128    = 'REASON FOR NTEQ ELIGIBILITY'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (T5 <= -1) THEN T5 = .;
   IF (T6 <= -1) THEN T6 = .;
   IF (T8 <= -1) THEN T8 = .;
   IF (T9 <= -1) THEN T9 = .;
   IF (T11 <= -1) THEN T11 = .;
   IF (T32 <= -1) THEN T32 = .;
   IF (T71 <= -1) THEN T71 = .;
   IF (T83 <= -1) THEN T83 = .;
   IF (T87 <= -1) THEN T87 = .;
   IF (T89 <= -1) THEN T89 = .;
   IF (T93 <= -1) THEN T93 = .;
   IF (T99M3 <= -1) THEN T99M3 = .;
   IF (T99M4 <= -1) THEN T99M4 = .;
   IF (PRGMTYPE <= -1) THEN PRGMTYPE = .;
   IF (TRT2 <= -1) THEN TRT2 = .;
   IF (PRG2 <= -1) THEN PRG2 = .;
   IF (CELL <= -1) THEN CELL = .;
   IF (CELL2 <= -1) THEN CELL2 = .;
   IF (T115 <= -1) THEN T115 = .;
   IF (T117 = 3) THEN T117 = .;
   IF (T117 <= -1) THEN T117 = .;
   IF (T119 = 3) THEN T119 = .;
   IF (T119 <= -1) THEN T119 = .;
   IF (T132 <= -1) THEN T132 = .;
   IF (T141 <= -1) THEN T141 = .;
   IF (T145 <= -1) THEN T145 = .;
   IF (T153 <= -1) THEN T153 = .;
   IF (T158 <= -1) THEN T158 = .;
   IF (T164M1 <= -1) THEN T164M1 = .;
   IF (T164M2 <= -1) THEN T164M2 = .;
   IF (T164M3 <= -1) THEN T164M3 = .;
   IF (T164M4 <= -1) THEN T164M4 = .;
   IF (T164M5 <= -1) THEN T164M5 = .;
   IF (T164M6 <= -1) THEN T164M6 = .;
   IF (T164M7 <= -1) THEN T164M7 = .;
   IF (T164M8 <= -1) THEN T164M8 = .;
   IF (T164M9 <= -1) THEN T164M9 = .;
   IF (T164M10 <= -1) THEN T164M10 = .;
   IF (T164M11 <= -1) THEN T164M11 = .;
   IF (T164M12 <= -1) THEN T164M12 = .;
   IF (T164M13 <= -1) THEN T164M13 = .;
   IF (T169 <= -1) THEN T169 = .;
   IF (T172 <= -1) THEN T172 = .;
   IF (T176 <= -1) THEN T176 = .;
   IF (T183 = 7) THEN T183 = .;
   IF (T183 <= -1) THEN T183 = .;
   IF (T191 = 6) THEN T191 = .;
   IF (T191 <= -1) THEN T191 = .;
   IF (T195 = 4) THEN T195 = .;
   IF (T195 <= -1) THEN T195 = .;
   IF (T198 = 4) THEN T198 = .;
   IF (T198 <= -1) THEN T198 = .;
   IF (T201 = 3) THEN T201 = .;
   IF (T201 <= -1) THEN T201 = .;
   IF (T203 <= -1) THEN T203 = .;
   IF (T211 <= -1) THEN T211 = .;
   IF (T213 <= -1) THEN T213 = .;
   IF (T215 <= -1) THEN T215 = .;
   IF (T217 <= -1) THEN T217 = .;
   IF (T221 <= -1) THEN T221 = .;
   IF (T225 <= -1) THEN T225 = .;
   IF (T229 <= -1) THEN T229 = .;
   IF (T233M1 <= -1) THEN T233M1 = .;
   IF (T233M2 <= -1) THEN T233M2 = .;
   IF (T233M3 <= -1) THEN T233M3 = .;
   IF (T233M4 <= -1) THEN T233M4 = .;
   IF (T233M5 <= -1) THEN T233M5 = .;
   IF (T233M6 <= -1) THEN T233M6 = .;
   IF (T233M7 <= -1) THEN T233M7 = .;
   IF (T233M8 <= -1) THEN T233M8 = .;
   IF (T233M9 <= -1) THEN T233M9 = .;
   IF (T233M10 <= -1) THEN T233M10 = .;
   IF (T233M11 <= -1) THEN T233M11 = .;
   IF (T233M12 <= -1) THEN T233M12 = .;
   IF (T233M13 <= -1) THEN T233M13 = .;
   IF (T241A1 <= -1) THEN T241A1 = .;
   IF (T241A2 <= -1) THEN T241A2 = .;
   IF (T241A3 <= -1) THEN T241A3 = .;
   IF (T241A4 <= -1) THEN T241A4 = .;
   IF (T241A5 <= -1) THEN T241A5 = .;
   IF (T241A6 <= -1) THEN T241A6 = .;
   IF (T241A7 <= -1) THEN T241A7 = .;
   IF (T241A8 <= -1) THEN T241A8 = .;
   IF (T241A9 <= -1) THEN T241A9 = .;
   IF (T241A10 <= -1) THEN T241A10 = .;
   IF (T241A11 <= -1) THEN T241A11 = .;
   IF (T241A12 <= -1) THEN T241A12 = .;
   IF (T243 <= -1) THEN T243 = .;
   IF (T246M1 <= -1) THEN T246M1 = .;
   IF (T246M2 <= -1) THEN T246M2 = .;
   IF (T246M3 <= -1) THEN T246M3 = .;
   IF (T246M4 <= -1) THEN T246M4 = .;
   IF (T246M5 <= -1) THEN T246M5 = .;
   IF (T246M6 <= -1) THEN T246M6 = .;
   IF (T246M7 <= -1) THEN T246M7 = .;
   IF (T246M8 <= -1) THEN T246M8 = .;
   IF (T246M9 <= -1) THEN T246M9 = .;
   IF (T246M11 <= -1) THEN T246M11 = .;
   IF (T246M12 <= -1) THEN T246M12 = .;
   IF (T246M13 <= -1) THEN T246M13 = .;
   IF (T246M14 <= -1) THEN T246M14 = .;
   IF (T247 <= -1) THEN T247 = .;
   IF (T248 <= -1) THEN T248 = .;
   IF (T250 <= -1) THEN T250 = .;
   IF (T251 <= -1) THEN T251 = .;
   IF (T252 <= -1) THEN T252 = .;
   IF (T253 <= -1) THEN T253 = .;
   IF (T255 <= -1) THEN T255 = .;
   IF (T257 <= -1) THEN T257 = .;
   IF (T261 <= -1) THEN T261 = .;
   IF (T262M1 <= -1) THEN T262M1 = .;
   IF (T262M2 <= -1) THEN T262M2 = .;
   IF (T262M3 <= -1) THEN T262M3 = .;
   IF (T263 <= -1) THEN T263 = .;
   IF (T264M1 <= -1) THEN T264M1 = .;
   IF (T264M2 <= -1) THEN T264M2 = .;
   IF (T264M3 <= -1) THEN T264M3 = .;
   IF (T265 <= -1) THEN T265 = .;
   IF (T266M1 <= -1) THEN T266M1 = .;
   IF (T266M2 <= -1) THEN T266M2 = .;
   IF (T266M3 <= -1) THEN T266M3 = .;
   IF (T267 <= -1) THEN T267 = .;
   IF (T268 <= -1) THEN T268 = .;
   IF (T269 <= -1) THEN T269 = .;
   IF (T270 <= -1) THEN T270 = .;
   IF (T272 = 3) THEN T272 = .;
   IF (T272 <= -1) THEN T272 = .;
   IF (T273 = 3) THEN T273 = .;
   IF (T273 <= -1) THEN T273 = .;
   IF (T274M1 = 3) THEN T274M1 = .;
   IF (T274M1 <= -1) THEN T274M1 = .;
   IF (T274M2 = 3) THEN T274M2 = .;
   IF (T274M2 <= -1) THEN T274M2 = .;
   IF (T274M3 = 3) THEN T274M3 = .;
   IF (T274M3 <= -1) THEN T274M3 = .;
   IF (T277 <= -1) THEN T277 = .;
   IF (T278 <= -1) THEN T278 = .;
   IF (T279 <= -1) THEN T279 = .;
   IF (T280 <= -1) THEN T280 = .;
   IF (T281 <= -1) THEN T281 = .;
   IF (T282 <= -1) THEN T282 = .;
   IF (T284 <= -1) THEN T284 = .;
   IF (T285M7 <= -1) THEN T285M7 = .;
   IF (T285M9 <= -1) THEN T285M9 = .;
   IF (T285M10 <= -1) THEN T285M10 = .;
   IF (T285M12 <= -1) THEN T285M12 = .;
   IF (T285M13 <= -1) THEN T285M13 = .;
   IF (T285M16 <= -1) THEN T285M16 = .;
   IF (T285M17 <= -1) THEN T285M17 = .;
   IF (T285M18 <= -1) THEN T285M18 = .;
   IF (T285M19 <= -1) THEN T285M19 = .;
   IF (T285M20 <= -1) THEN T285M20 = .;
   IF (T285M21 <= -1) THEN T285M21 = .;
   IF (T285M22 <= -1) THEN T285M22 = .;
   IF (T286 <= -1) THEN T286 = .;
   IF (T287 = 3) THEN T287 = .;
   IF (T287 <= -1) THEN T287 = .;
   IF (T289 <= -1) THEN T289 = .;
   IF (T291 <= -1) THEN T291 = .;
   IF (T295 <= -1) THEN T295 = .;
   IF (T297 <= -1) THEN T297 = .;
   IF (T298 <= -1) THEN T298 = .;
   IF (T299M1 <= -1) THEN T299M1 = .;
   IF (T299M2 <= -1) THEN T299M2 = .;
   IF (T299M3 <= -1) THEN T299M3 = .;
   IF (T300 <= -1) THEN T300 = .;
   IF (T307 <= -1) THEN T307 = .;
   IF (T309 <= -1) THEN T309 = .;
   IF (T310 <= -1) THEN T310 = .;
   IF (T312 <= -1) THEN T312 = .;
   IF (T313 <= -1) THEN T313 = .;
   IF (T315 <= -1) THEN T315 = .;
   IF (T316 <= -1) THEN T316 = .;
   IF (T321 <= -1) THEN T321 = .;
   IF (T324M1 <= -1) THEN T324M1 = .;
   IF (T324M2 <= -1) THEN T324M2 = .;
   IF (T324M3 <= -1) THEN T324M3 = .;
   IF (T326 <= -1) THEN T326 = .;
   IF (T331 <= -1) THEN T331 = .;
   IF (T333M1 <= -1) THEN T333M1 = .;
   IF (T333M2 <= -1) THEN T333M2 = .;
   IF (T333M3 <= -1) THEN T333M3 = .;
   IF (T334 <= -1) THEN T334 = .;
   IF (T335 <= -1) THEN T335 = .;
   IF (T336M1 <= -1) THEN T336M1 = .;
   IF (T336M2 <= -1) THEN T336M2 = .;
   IF (T336M3 <= -1) THEN T336M3 = .;
   IF (T338 <= -1) THEN T338 = .;
   IF (T339 <= -1) THEN T339 = .;
   IF (T340M1 <= -1) THEN T340M1 = .;
   IF (T340M2 <= -1) THEN T340M2 = .;
   IF (T340M3 <= -1) THEN T340M3 = .;
   IF (T341 <= -1) THEN T341 = .;
   IF (T342 <= -1) THEN T342 = .;
   IF (T343M1 <= -1) THEN T343M1 = .;
   IF (T343M2 <= -1) THEN T343M2 = .;
   IF (T343M3 <= -1) THEN T343M3 = .;
   IF (T344 <= -1) THEN T344 = .;
   IF (T346 <= -1) THEN T346 = .;
   IF (T347M1 <= -1) THEN T347M1 = .;
   IF (T347M2 <= -1) THEN T347M2 = .;
   IF (T347M3 <= -1) THEN T347M3 = .;
   IF (T348 <= -1) THEN T348 = .;
   IF (T349 <= -1) THEN T349 = .;
   IF (T350M1 <= -1) THEN T350M1 = .;
   IF (T350M2 <= -1) THEN T350M2 = .;
   IF (T350M3 <= -1) THEN T350M3 = .;
   IF (T357 <= -1) THEN T357 = .;
   IF (T358M1 <= -1) THEN T358M1 = .;
   IF (T358M2 <= -1) THEN T358M2 = .;
   IF (T358M3 <= -1) THEN T358M3 = .;
   IF (T358M4 <= -1) THEN T358M4 = .;
   IF (T358M5 <= -1) THEN T358M5 = .;
   IF (T358M6 <= -1) THEN T358M6 = .;
   IF (T358M7 <= -1) THEN T358M7 = .;
   IF (T362M1 <= -1) THEN T362M1 = .;
   IF (T362M2 <= -1) THEN T362M2 = .;
   IF (T362M3 <= -1) THEN T362M3 = .;
   IF (T364 <= -1) THEN T364 = .;
   IF (T365 <= -1) THEN T365 = .;
   IF (T369 <= -1) THEN T369 = .;
   IF (T374 <= -1) THEN T374 = .;
   IF (T376M1 <= -1) THEN T376M1 = .;
   IF (T381 <= -1) THEN T381 = .;
   IF (T383 <= -1) THEN T383 = .;
   IF (T384 <= -1) THEN T384 = .;
   IF (T385 <= -1) THEN T385 = .;
   IF (T386 <= -1) THEN T386 = .;
   IF (T388 <= -1) THEN T388 = .;
   IF (T389M1 <= -1) THEN T389M1 = .;
   IF (T389M2 <= -1) THEN T389M2 = .;
   IF (T389M3 <= -1) THEN T389M3 = .;
   IF (T390 <= -1) THEN T390 = .;
   IF (T392 <= -1) THEN T392 = .;
   IF (T393M1 <= -1) THEN T393M1 = .;
   IF (T393M2 <= -1) THEN T393M2 = .;
   IF (T393M3 <= -1) THEN T393M3 = .;
   IF (T394 <= -1) THEN T394 = .;
   IF (T398 <= -1) THEN T398 = .;
   IF (T401 = 3) THEN T401 = .;
   IF (T401 <= -1) THEN T401 = .;
   IF (T403 <= -1) THEN T403 = .;
   IF (T404M1 <= -1) THEN T404M1 = .;
   IF (T404M2 <= -1) THEN T404M2 = .;
   IF (T404M3 <= -1) THEN T404M3 = .;
   IF (T409 <= -1) THEN T409 = .;
   IF (T410 <= -1) THEN T410 = .;
   IF (T417 = 3) THEN T417 = .;
   IF (T417 <= -1) THEN T417 = .;
   IF (T418 = 3) THEN T418 = .;
   IF (T418 <= -1) THEN T418 = .;
   IF (T420 <= -1) THEN T420 = .;
   IF (T422 <= -1) THEN T422 = .;
   IF (T424 <= -1) THEN T424 = .;
   IF (T426M1 <= -1) THEN T426M1 = .;
   IF (T426M2 <= -1) THEN T426M2 = .;
   IF (T426M3 <= -1) THEN T426M3 = .;
   IF (T426M4 <= -1) THEN T426M4 = .;
   IF (T426M5 <= -1) THEN T426M5 = .;
   IF (T426M6 <= -1) THEN T426M6 = .;
   IF (T426M7 <= -1) THEN T426M7 = .;
   IF (T426M8 <= -1) THEN T426M8 = .;
   IF (T426M9 <= -1) THEN T426M9 = .;
   IF (T426M10 <= -1) THEN T426M10 = .;
   IF (T428M1 <= -1) THEN T428M1 = .;
   IF (T428M2 <= -1) THEN T428M2 = .;
   IF (T428M3 <= -1) THEN T428M3 = .;
   IF (T429 <= -1) THEN T429 = .;
   IF (T431 <= -1) THEN T431 = .;
   IF (T434M1 <= -1) THEN T434M1 = .;
   IF (T434M2 <= -1) THEN T434M2 = .;
   IF (T434M3 <= -1) THEN T434M3 = .;
   IF (T435 = 3) THEN T435 = .;
   IF (T435 <= -1) THEN T435 = .;
   IF (T436 = 3) THEN T436 = .;
   IF (T436 <= -1) THEN T436 = .;
   IF (T437M1 = 3) THEN T437M1 = .;
   IF (T437M1 <= -1) THEN T437M1 = .;
   IF (T437M2 = 3) THEN T437M2 = .;
   IF (T437M2 <= -1) THEN T437M2 = .;
   IF (T437M3 = 3) THEN T437M3 = .;
   IF (T437M3 <= -1) THEN T437M3 = .;
   IF (T438 = 5) THEN T438 = .;
   IF (T438 <= -1) THEN T438 = .;
   IF (T446 <= -1) THEN T446 = .;
   IF (T448 <= -1) THEN T448 = .;
   IF (T452 <= -1) THEN T452 = .;
   IF (T454 <= -1) THEN T454 = .;
   IF (T455 <= -1) THEN T455 = .;
   IF (T457 <= -1) THEN T457 = .;
   IF (T459M1 <= -1) THEN T459M1 = .;
   IF (T459M2 <= -1) THEN T459M2 = .;
   IF (T459M3 <= -1) THEN T459M3 = .;
   IF (T461 <= -1) THEN T461 = .;
   IF (T463M1 <= -1) THEN T463M1 = .;
   IF (T463M2 <= -1) THEN T463M2 = .;
   IF (T463M3 <= -1) THEN T463M3 = .;
   IF (T464 <= -1) THEN T464 = .;
   IF (T465M1 <= -1) THEN T465M1 = .;
   IF (T465M2 <= -1) THEN T465M2 = .;
   IF (T465M3 <= -1) THEN T465M3 = .;
   IF (T466 <= -1) THEN T466 = .;
   IF (T469 <= -1) THEN T469 = .;
   IF (T472 <= -1) THEN T472 = .;
   IF (T475M1 <= -1) THEN T475M1 = .;
   IF (T475M2 <= -1) THEN T475M2 = .;
   IF (T475M3 <= -1) THEN T475M3 = .;
   IF (T480 <= -1) THEN T480 = .;
   IF (T484 <= -1) THEN T484 = .;
   IF (T485 <= -1) THEN T485 = .;
   IF (T486M1 <= -1) THEN T486M1 = .;
   IF (T486M2 <= -1) THEN T486M2 = .;
   IF (T486M3 <= -1) THEN T486M3 = .;
   IF (T487 <= -1) THEN T487 = .;
   IF (T488 <= -1) THEN T488 = .;
   IF (T489M1 <= -1) THEN T489M1 = .;
   IF (T489M2 <= -1) THEN T489M2 = .;
   IF (T489M3 <= -1) THEN T489M3 = .;
   IF (T490 <= -1) THEN T490 = .;
   IF (T491 <= -1) THEN T491 = .;
   IF (T492M1 <= -1) THEN T492M1 = .;
   IF (T492M2 <= -1) THEN T492M2 = .;
   IF (T492M3 <= -1) THEN T492M3 = .;
   IF (T500 <= -1) THEN T500 = .;
   IF (T509 <= -1) THEN T509 = .;
   IF (T513 <= -1) THEN T513 = .;
   IF (T516M1 <= -1) THEN T516M1 = .;
   IF (T516M2 <= -1) THEN T516M2 = .;
   IF (T516M3 <= -1) THEN T516M3 = .;
   IF (T516M4 <= -1) THEN T516M4 = .;
   IF (T516M5 <= -1) THEN T516M5 = .;
   IF (T516M6 <= -1) THEN T516M6 = .;
   IF (T516M7 <= -1) THEN T516M7 = .;
   IF (T516M8 <= -1) THEN T516M8 = .;
   IF (T516M9 <= -1) THEN T516M9 = .;
   IF (T516M10 <= -1) THEN T516M10 = .;
   IF (T518 <= -1) THEN T518 = .;
   IF (T519M1 <= -1) THEN T519M1 = .;
   IF (T519M2 <= -1) THEN T519M2 = .;
   IF (T519M3 <= -1) THEN T519M3 = .;
   IF (T520 <= -1) THEN T520 = .;
   IF (T523 <= -1) THEN T523 = .;
   IF (T547 <= -1) THEN T547 = .;
   IF (T554 <= -1) THEN T554 = .;
   IF (T128 <= -1) THEN T128 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT T5 t5ffffff. T6 t6ffffff. T8 t8ffffff.
         T9 t9ffffff. T11 t11fffff. T32 t32fffff.
         T71 t71fffff. T83 t83fffff. T87 t87fffff.
         T89 t89fffff. T93 t93fffff. T99M3 t99m3fff.
         T99M4 t99m4fff. PRGMTYPE prgmtype. TRT2 trt2ffff.
         PRG2 prg2ffff. CELL cell. CELL2 cell2fff.
         T115 t115ffff. T117 t117ffff. T119 t119ffff.
         T132 t132ffff. T141 t141ffff. T145 t145ffff.
         T153 t153ffff. T158 t158ffff. T164M1 t164m1ff.
         T164M2 t164m2ff. T164M3 t164m3ff. T164M4 t164m4ff.
         T164M5 t164m5ff. T164M6 t164m6ff. T164M7 t164m7ff.
         T164M8 t164m8ff. T164M9 t164m9ff. T164M10 t164m10f.
         T164M11 t164m11f. T164M12 t164m12f. T164M13 t164m13f.
         T169 t169ffff. T172 t172ffff. T176 t176ffff.
         T183 t183ffff. T191 t191ffff. T195 t195ffff.
         T198 t198ffff. T201 t201ffff. T203 t203ffff.
         T211 t211ffff. T213 t213ffff. T215 t215ffff.
         T217 t217ffff. T221 t221ffff. T225 t225ffff.
         T229 t229ffff. T233M1 t233m1ff. T233M2 t233m2ff.
         T233M3 t233m3ff. T233M4 t233m4ff. T233M5 t233m5ff.
         T233M6 t233m6ff. T233M7 t233m7ff. T233M8 t233m8ff.
         T233M9 t233m9ff. T233M10 t233m10f. T233M11 t233m11f.
         T233M12 t233m12f. T233M13 t233m13f. T241A1 t241a1ff.
         T241A2 t241a2ff. T241A3 t241a3ff. T241A4 t241a4ff.
         T241A5 t241a5ff. T241A6 t241a6ff. T241A7 t241a7ff.
         T241A8 t241a8ff. T241A9 t241a9ff. T241A10 t241a10f.
         T241A11 t241a11f. T241A12 t241a12f. T243 t243ffff.
         T246M1 t246m1ff. T246M2 t246m2ff. T246M3 t246m3ff.
         T246M4 t246m4ff. T246M5 t246m5ff. T246M6 t246m6ff.
         T246M7 t246m7ff. T246M8 t246m8ff. T246M9 t246m9ff.
         T246M11 t246m11f. T246M12 t246m12f. T246M13 t246m13f.
         T246M14 t246m14f. T247 t247ffff. T248 t248ffff.
         T250 t250ffff. T251 t251ffff. T252 t252ffff.
         T253 t253ffff. T255 t255ffff. T257 t257ffff.
         T261 t261ffff. T262M1 t262m1ff. T262M2 t262m2ff.
         T262M3 t262m3ff. T263 t263ffff. T264M1 t264m1ff.
         T264M2 t264m2ff. T264M3 t264m3ff. T265 t265ffff.
         T266M1 t266m1ff. T266M2 t266m2ff. T266M3 t266m3ff.
         T267 t267ffff. T268 t268ffff. T269 t269ffff.
         T270 t270ffff. T272 t272ffff. T273 t273ffff.
         T274M1 t274m1ff. T274M2 t274m2ff. T274M3 t274m3ff.
         T277 t277ffff. T278 t278ffff. T279 t279ffff.
         T280 t280ffff. T281 t281ffff. T282 t282ffff.
         T284 t284ffff. T285M7 t285m7ff. T285M9 t285m9ff.
         T285M10 t285m10f. T285M12 t285m12f. T285M13 t285m13f.
         T285M16 t285m16f. T285M17 t285m17f. T285M18 t285m18f.
         T285M19 t285m19f. T285M20 t285m20f. T285M21 t285m21f.
         T285M22 t285m22f. T286 t286ffff. T287 t287ffff.
         T289 t289ffff. T291 t291ffff. T295 t295ffff.
         T297 t297ffff. T298 t298ffff. T299M1 t299m1ff.
         T299M2 t299m2ff. T299M3 t299m3ff. T300 t300ffff.
         T307 t307ffff. T309 t309ffff. T310 t310ffff.
         T312 t312ffff. T313 t313ffff. T315 t315ffff.
         T316 t316ffff. T321 t321ffff. T324M1 t324m1ff.
         T324M2 t324m2ff. T324M3 t324m3ff. T326 t326ffff.
         T331 t331ffff. T333M1 t333m1ff. T333M2 t333m2ff.
         T333M3 t333m3ff. T334 t334ffff. T335 t335ffff.
         T336M1 t336m1ff. T336M2 t336m2ff. T336M3 t336m3ff.
         T338 t338ffff. T339 t339ffff. T340M1 t340m1ff.
         T340M2 t340m2ff. T340M3 t340m3ff. T341 t341ffff.
         T342 t342ffff. T343M1 t343m1ff. T343M2 t343m2ff.
         T343M3 t343m3ff. T344 t344ffff. T346 t346ffff.
         T347M1 t347m1ff. T347M2 t347m2ff. T347M3 t347m3ff.
         T348 t348ffff. T349 t349ffff. T350M1 t350m1ff.
         T350M2 t350m2ff. T350M3 t350m3ff. T357 t357ffff.
         T358M1 t358m1ff. T358M2 t358m2ff. T358M3 t358m3ff.
         T358M4 t358m4ff. T358M5 t358m5ff. T358M6 t358m6ff.
         T358M7 t358m7ff. T362M1 t362m1ff. T362M2 t362m2ff.
         T362M3 t362m3ff. T364 t364ffff. T365 t365ffff.
         T369 t369ffff. T374 t374ffff. T376M1 t376m1ff.
         T381 t381ffff. T383 t383ffff. T384 t384ffff.
         T385 t385ffff. T386 t386ffff. T388 t388ffff.
         T389M1 t389m1ff. T389M2 t389m2ff. T389M3 t389m3ff.
         T390 t390ffff. T392 t392ffff. T393M1 t393m1ff.
         T393M2 t393m2ff. T393M3 t393m3ff. T394 t394ffff.
         T398 t398ffff. T401 t401ffff. T403 t403ffff.
         T404M1 t404m1ff. T404M2 t404m2ff. T404M3 t404m3ff.
         T409 t409ffff. T410 t410ffff. T417 t417ffff.
         T418 t418ffff. T420 t420ffff. T422 t422ffff.
         T424 t424ffff. T426M1 t426m1ff. T426M2 t426m2ff.
         T426M3 t426m3ff. T426M4 t426m4ff. T426M5 t426m5ff.
         T426M6 t426m6ff. T426M7 t426m7ff. T426M8 t426m8ff.
         T426M9 t426m9ff. T426M10 t426m10f. T428M1 t428m1ff.
         T428M2 t428m2ff. T428M3 t428m3ff. T429 t429ffff.
         T431 t431ffff. T434M1 t434m1ff. T434M2 t434m2ff.
         T434M3 t434m3ff. T435 t435ffff. T436 t436ffff.
         T437M1 t437m1ff. T437M2 t437m2ff. T437M3 t437m3ff.
         T438 t438ffff. T446 t446ffff. T448 t448ffff.
         T452 t452ffff. T454 t454ffff. T455 t455ffff.
         T457 t457ffff. T459M1 t459m1ff. T459M2 t459m2ff.
         T459M3 t459m3ff. T461 t461ffff. T463M1 t463m1ff.
         T463M2 t463m2ff. T463M3 t463m3ff. T464 t464ffff.
         T465M1 t465m1ff. T465M2 t465m2ff. T465M3 t465m3ff.
         T466 t466ffff. T469 t469ffff. T472 t472ffff.
         T475M1 t475m1ff. T475M2 t475m2ff. T475M3 t475m3ff.
         T480 t480ffff. T484 t484ffff. T485 t485ffff.
         T486M1 t486m1ff. T486M2 t486m2ff. T486M3 t486m3ff.
         T487 t487ffff. T488 t488ffff. T489M1 t489m1ff.
         T489M2 t489m2ff. T489M3 t489m3ff. T490 t490ffff.
         T491 t491ffff. T492M1 t492m1ff. T492M2 t492m2ff.
         T492M3 t492m3ff. T500 t500ffff. T509 t509ffff.
         T513 t513ffff. T516M1 t516m1ff. T516M2 t516m2ff.
         T516M3 t516m3ff. T516M4 t516m4ff. T516M5 t516m5ff.
         T516M6 t516m6ff. T516M7 t516m7ff. T516M8 t516m8ff.
         T516M9 t516m9ff. T516M10 t516m10f. T518 t518ffff.
         T519M1 t519m1ff. T519M2 t519m2ff. T519M3 t519m3ff.
         T520 t520ffff. T523 t523ffff. T547 t547ffff.
         T554 t554ffff. T128 t128ffff.  ;
*/

RUN ;
